@@ -8,7 +8,7 @@ from cdislogging import get_logger
 import gen3git
 
 from gen3utils.manifest.manifest_validator import version_is_branch
-
+from gen3utils.utils import submit_comment
 
 logger = get_logger("comment-deployment-changes", log_level="info")
 
@@ -29,14 +29,15 @@ IGNORED_SERVICES = [
 # block is not the same as the repo name. services that are not
 # listed here are assumed to be in repo uc-cdis/<service name>.
 SERVICE_TO_REPO = {
-    "covid19-etl": "covid19-tools",
     "dashboard": "gen3-statics",
-    "nb-etl": "covid19-tools",
     "portal": "data-portal",
     "revproxy": "docker-nginx",
     "spark": "gen3-spark",
     "wts": "workspace-token-service",
     "metadata": "metadata-service",
+    "covid19-etl": "covid19-tools",
+    "nb-etl": "covid19-tools",
+    "covid19-bayes-model": "covid19model",
     "data-ingestion-pipeline": "bdcat-data-ingestion",
 }
 
@@ -297,9 +298,3 @@ def generate_comment(deployment_changes, services_on_branch):
         for service, items in deployment_changes.items():
             contents += "- {}\n  - {}\n".format(service, "\n  - ".join(items))
     return contents
-
-
-def submit_comment(contents, headers, pr_comments_url):
-    res = requests.post(pr_comments_url, json={"body": contents}, headers=headers)
-    if res.status_code != 201:
-        logger.error("Failed to write comment:", res.status_code, res.json())
